window.Gleam.initSearch([{"doc":"defangle","title":"defangle","content":"# 🦇 defangle\n\n[![Package Version](https://img.shields.io/hexpm/v/defangle)](https://hex.pm/packages/defangle)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/defangle/)\n\nDefangle is a Gleam library for defanging URLs, Emails, and IP addresses making them safe to share.\n\n&lt;img src=&quot;https://github.com/brittonhayes/defangle/blob/main/.github/assets/defangle-logo.png&quot; width=&quot;120&quot;&gt;\n\n## 📥 Install defangle\n\n```sh\ngleam add defangle\n```\n\n## ⚡ Usage\n\n```gleam\nimport defangle\n\npub fn main() {\n  \n  // Defang a URL to make it safe to share\n  &quot;https://www.suspicious-url.com&quot;\n  |&gt; defangle.defang_url\n  // &quot;hxxps[://]www[.]suspicious-url[.]com&quot;\n\n  // Defang an email address to make it safe to share\n  &quot;lucy@malicious.gleam&quot;\n  |&gt; defangle.defang_email\n  // &quot;lucy[at]suspicious-url[.]com&quot;\n\n  // Defang an IP address to make it safe to share\n  &quot;103.253.144.32&quot;\n  |&gt; defangle.defang_ip\n  // &quot;103[.]253[.]144[.]32&quot;\n  \n  // Defang an IPv6 address to make it safe to share\n  &quot;2001:0db8:85a3:0000:0000:8a2e:0370:7334&quot;\n  |&gt; defangle.defang_ip\n  // &quot;2001[:]0db8[:]85a3[:]0000[:]0000[:]8a2e[:]0370[:]7334\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/defangle&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"defangle","title":"defang","content":"pub fn defang(url: String) -&gt; String\n Replace the `.` in the URL with `[.]`, \n and the `http` with `hxxp`, \n and the `://` with `[://]`\nSynonyms:\ndefangle.defang\ndefangle defang","url":"defangle.html#defang"},{"doc":"defangle","title":"defang_email","content":"pub fn defang_email(user: String, domain: String) -&gt; String\n Replace the `@` in the email with `[at]`,\n and the `.` with `[.]`\nSynonyms:\ndefangle.defang_email\ndefangle defang_email","url":"defangle.html#defang_email"},{"doc":"defangle","title":"defang_ip","content":"pub fn defang_ip(ip: String) -&gt; String\n Replace the `.` in the IP address with `[.]`\nSynonyms:\ndefangle.defang_ip\ndefangle defang_ip","url":"defangle.html#defang_ip"},{"doc":"defangle","title":"defang_url","content":"pub fn defang_url(domain: String) -&gt; String\n\nSynonyms:\ndefangle.defang_url\ndefangle defang_url","url":"defangle.html#defang_url"},{"doc":"defangle","title":"defangle","content":" Defangle contains functions for defanging IP addresses, URLs, and email addresses.\n Defanging is the process of replacing certain characters in links to make\n them safe to share in contexts where they might otherwise be clicked.","url":"defangle.html"}]);